@@ -1,4 +1,4 @@
-use colour::{green_ln, red_ln};
+use colour::{green_ln, red_ln, yellow_ln};
 use human_panic::setup_panic;
 use structopt::StructOpt;
 
@@ -14,16 +14,6 @@ async fn main() {
 
     loop {
         match dezoomify(&args).await {
-            Err(err) => {
-                red_ln!("ERROR {}", err);
-                has_errors = true;
-                // If we have reached the end of stdin, we exit
-                if let ZoomError::Io { source } = err {
-                    if source.kind() == std::io::ErrorKind::UnexpectedEof {
-                        break
-                    }
-                }
-            },
             Ok(saved_as) => {
                 green_ln!("Image successfully saved to '{}' (current working directory: {})",
                          saved_as.to_string_lossy(),
@@ -32,6 +22,19 @@ async fn main() {
                              .unwrap_or_else(|_e| "unknown".into())
                 );
             }
+            Err(ZoomError::Io { source }) if source.kind() == std::io::ErrorKind::UnexpectedEof => {
+                // If we have reached the end of stdin, we exit
+                yellow_ln!("Reached end of input. Exiting...");
+                break
+            },
+            Err(err @ ZoomError::PartialDownload { .. }) => {
+                yellow_ln!("{}", err);
+                has_errors = true;
+            },
+            Err(err) => {
+                red_ln!("ERROR {}", err);
+                has_errors = true;
+            },
         }
         if has_args {
             // Command-line invocation
